@@ -41,7 +41,7 @@ def mouse_preprocess(mouse_keycode: [int, str], x: int, y: int):
         if y is None:
             y = now_y
     except AutoControlMouseException as error:
-        raise AutoControlMouseException(mouse_get_position + repr(error))
+        raise AutoControlMouseException(mouse_get_position + " " + repr(error))
     return mouse_keycode, x, y
 
 
@@ -55,7 +55,7 @@ def position():
             record_total("position", None)
             return mouse.position()
         except AutoControlMouseException as error:
-            raise AutoControlMouseException(mouse_get_position + repr(error))
+            raise AutoControlMouseException(mouse_get_position + " " + repr(error))
     except Exception as error:
         record_total("position", None, repr(error))
         print(repr(error), file=sys.stderr)
@@ -74,9 +74,9 @@ def set_position(x: int, y: int):
             record_total("position", param)
             return x, y
         except AutoControlMouseException as error:
-            raise AutoControlMouseException(mouse_set_position + repr(error))
+            raise AutoControlMouseException(mouse_set_position + " " + repr(error))
         except ctypes.ArgumentError as error:
-            raise AutoControlMouseException(mouse_wrong_value + repr(error))
+            raise AutoControlMouseException(mouse_wrong_value + " " + repr(error))
     except Exception as error:
         record_total("set_position", param, repr(error))
         print(repr(error), file=sys.stderr)
@@ -101,7 +101,7 @@ def press_mouse(mouse_keycode: [int, str], x: int = None, y: int = None):
             record_total("press_mouse", param)
             return mouse_keycode, x, y
         except AutoControlMouseException as error:
-            raise AutoControlMouseException(mouse_press_mouse + repr(error))
+            raise AutoControlMouseException(mouse_press_mouse + " " + repr(error))
         except TypeError as error:
             raise AutoControlMouseException(repr(error))
     except Exception as error:
@@ -128,7 +128,7 @@ def release_mouse(mouse_keycode: [int, str], x: int = None, y: int = None):
             record_total("press_mouse", param)
             return mouse_keycode, x, y
         except AutoControlMouseException as error:
-            raise AutoControlMouseException(mouse_release_mouse + repr(error))
+            raise AutoControlMouseException(mouse_release_mouse + " " + repr(error))
         except TypeError as error:
             raise AutoControlMouseException(repr(error))
     except Exception as error:
@@ -152,7 +152,7 @@ def click_mouse(mouse_keycode: [int, str], x: int = None, y: int = None):
             record_total("click_mouse", param)
             return mouse_keycode, x, y
         except AutoControlMouseException as error:
-            raise AutoControlMouseException(mouse_click_mouse + repr(error))
+            raise AutoControlMouseException(mouse_click_mouse + " " + repr(error))
         except TypeError as error:
             raise AutoControlMouseException(repr(error))
     except Exception as error:
@@ -203,7 +203,7 @@ def scroll(scroll_value: int, x: int = None, y: int = None, scroll_direction: st
             record_total("scroll", param)
             return scroll_value, scroll_direction
         except AutoControlMouseException as error:
-            raise AutoControlMouseException(mouse_scroll + repr(error))
+            raise AutoControlMouseException(mouse_scroll + " " + repr(error))
         except TypeError as error:
             raise AutoControlMouseException(repr(error))
     except Exception as error:
